@@ -4,8 +4,9 @@
 from __future__ import print_function
 
 import codecs
+from io import BytesIO
+
 import pytest
-from six import text_type, binary_type, BytesIO, PY2
 from unittest import TestCase
 
 import latexcodec
@@ -27,15 +28,14 @@ def test_latex_incremental_decoder_getstate():
 
 def test_latex_incremental_decoder_setstate():
     encoder = codecs.getincrementaldecoder('latex')()
-    state = (u'', 0)
+    state = (b'', 0)
     with pytest.raises(NotImplementedError):
         encoder.setstate(state)
 
 
 def split_input(input_):
     """Helper function for testing the incremental encoder and decoder."""
-    if not isinstance(input_, (text_type, binary_type)):
-        raise TypeError("expected unicode or bytes input")
+    assert isinstance(input_, (str, bytes))
     if input_:
         for i in range(len(input_)):
             if i + 1 < len(input_):
@@ -59,15 +59,15 @@ class TestDecoder(TestCase):
 
     def test_invalid_type(self):
         with pytest.raises(TypeError):
-            codecs.getdecoder("latex")(object())
+            codecs.getdecoder("latex")(object())  # type: ignore
 
     def test_invalid_code(self):
         with pytest.raises(ValueError):
             # b'\xe9' is invalid utf-8 code
-            self.decode(u'', b'\xe9  ', 'utf-8')
+            self.decode('', b'\xe9  ', 'utf-8')
 
     def test_null(self):
-        self.decode(u'', b'')
+        self.decode('', b'')
 
     def test_maelstrom(self):
         self.decode(u"mælström", br'm\ae lstr\"om')
@@ -183,31 +183,31 @@ class TestDecoder(TestCase):
                     br'\textogonekcentered{\=O}\textogonekcentered{\=o}')
 
     def test_math_spacing_dollar(self):
-        self.decode(u'This is a ψ test.', br'This is a $\psi$ test.')
+        self.decode('This is a ψ test.', br'This is a $\psi$ test.')
 
     def test_math_spacing_brace(self):
-        self.decode(u'This is a ψ test.', br'This is a \(\psi\) test.')
+        self.decode('This is a ψ test.', br'This is a \(\psi\) test.')
 
     def test_double_math(self):
         # currently no attempt to translate maths inside $$
-        self.decode(u'This is a $$\\psi $$ test.',
+        self.decode('This is a $$\\psi $$ test.',
                     br'This is a $$\psi$$ test.')
 
     def test_tilde(self):
-        self.decode(u'This is a ˜, ˷, ∼ and ~test.',
+        self.decode('This is a ˜, ˷, ∼ and ~test.',
                     (br'This is a \~{}, \texttildelow, '
                      br'$\sim$ and \textasciitilde test.'))
 
     def test_backslash(self):
-        self.decode(u'This is a \\ \\test.',
+        self.decode('This is a \\ \\test.',
                     br'This is a $\backslash$ \textbackslash test.')
 
     def test_percent(self):
-        self.decode(u'This is a % test.',
+        self.decode('This is a % test.',
                     br'This is a \% test.')
 
     def test_math_minus(self):
-        self.decode(u'This is a − test.',
+        self.decode('This is a − test.',
                     br'This is a $-$ test.')
 
     def test_swedish_again(self):
@@ -224,6 +224,9 @@ class TestDecoder(TestCase):
     def test_double_quotes_gb2312(self):
         self.decode(u"“你好”", u"``你好''".encode('gb2312'), 'gb2312')
 
+    def test_ell(self):
+        self.decode(u"ℓ", br"$\ell$")
+
     def test_theta(self):
         self.decode(u"θ", br"$\theta$")
         self.decode(u"θ", br"\texttheta")
@@ -240,6 +243,10 @@ class TestDecoder(TestCase):
     def test_decode_guillemet(self):
         self.decode(u"«quote»", br"\guillemotleft quote\guillemotright")
 
+    def test_decode_reals(self):
+        self.decode(u"ℝ", br"$\mathbb R$")
+        self.decode(u"ℝ", br"$\mathbb{R}$")
+
 
 class TestStreamDecoder(TestDecoder):
 
@@ -252,12 +259,8 @@ class TestStreamDecoder(TestDecoder):
         self.assertEqual(text_utf8, reader.read())
 
     # in this test, BytesIO(object()) is eventually called
-    # this is valid on Python 2, so we skip this test there
     def test_invalid_type(self):
-        if PY2:
-            pytest.skip("test not relevant for Python 2")
-        else:
-            TestDecoder.test_invalid_type(self)
+        TestDecoder.test_invalid_type(self)
 
 
 class TestIncrementalDecoder(TestDecoder):
@@ -270,7 +273,7 @@ class TestIncrementalDecoder(TestDecoder):
         decoded_parts = (
             decoder.decode(text_latex_part, final)
             for text_latex_part, final in split_input(text_latex))
-        self.assertEqual(text_utf8, u''.join(decoded_parts))
+        self.assertEqual(text_utf8, ''.join(decoded_parts))
 
 
 class TestEncoder(TestCase):
@@ -285,28 +288,28 @@ class TestEncoder(TestCase):
 
     def test_invalid_type(self):
         with pytest.raises(TypeError):
-            codecs.getencoder("latex")(object())
+            codecs.getencoder("latex")(object())  # type: ignore
 
     # note concerning test_invalid_code_* methods:
-    # u'\u2328' (0x2328 = 9000) is unicode for keyboard symbol
+    # '\u2328' (0x2328 = 9000) is unicode for keyboard symbol
     # we currently provide no translation for this into LaTeX code
 
     def test_invalid_code_strict(self):
         with pytest.raises(ValueError):
-            self.encode(u'\u2328', b'', 'ascii', 'strict')
+            self.encode('\u2328', b'', 'ascii', 'strict')
 
     def test_invalid_code_ignore(self):
-        self.encode(u'\u2328', b'', 'ascii', 'ignore')
+        self.encode('\u2328', b'', 'ascii', 'ignore')
 
     def test_invalid_code_replace(self):
-        self.encode(u'\u2328', b'{\\char9000}', 'ascii', 'replace')
+        self.encode('\u2328', b'{\\char9000}', 'ascii', 'replace')
 
     def test_invalid_code_baderror(self):
         with pytest.raises(ValueError):
-            self.encode(u'\u2328', b'', 'ascii', '**baderror**')
+            self.encode('\u2328', b'', 'ascii', '**baderror**')
 
     def test_null(self):
-        self.encode(u'', b'')
+        self.encode('', b'')
 
     def test_maelstrom(self):
         self.encode(u"mælström", br'm\ae lstr\"om')
@@ -401,23 +404,23 @@ class TestEncoder(TestCase):
                     br'\textogonekcentered{\=O}\textogonekcentered{\=o}')
 
     def test_math_spacing(self):
-        self.encode(u'This is a ψ test.', br'This is a $\psi$ test.')
+        self.encode('This is a ψ test.', br'This is a $\psi$ test.')
 
     def test_double_math(self):
         # currently no attempt to translate maths inside $$
-        self.encode(u'This is a $$\\psi$$ test.', br'This is a $$\psi$$ test.')
+        self.encode('This is a $$\\psi$$ test.', br'This is a $$\psi$$ test.')
 
     def test_tilde(self):
-        self.encode(u'This is a ˜, ˷, ∼ and ~test.',
+        self.encode('This is a ˜, ˷, ∼ and ~test.',
                     (br'This is a \~{}, \texttildelow , '
                      br'$\sim$ and \textasciitilde test.'))
 
     def test_percent(self):
-        self.encode(u'This is a % test.',
+        self.encode('This is a % test.',
                     br'This is a \% test.')
 
     def test_hyphen(self):
-        self.encode(u'This is a \N{HYPHEN} test.',
+        self.encode('This is a \N{HYPHEN} test.',
                     br'This is a - test.')
 
     def test_math_minus(self):
@@ -433,6 +436,9 @@ class TestEncoder(TestCase):
     def test_thin_space(self):
         self.encode(u"a\u2009b", b"a b")
 
+    def test_ell(self):
+        self.encode(u"ℓ", br"$\ell$")
+
     def test_theta(self):
         self.encode(u"θ", br"$\theta$")
 
@@ -442,6 +448,15 @@ class TestEncoder(TestCase):
     def test_encode_guillemet(self):
         self.encode(u"«quote»", br"\guillemotleft quote\guillemotright")
 
+    def test_encode_reals(self):
+        self.encode(u"ℝ", br"$\mathbb R$")
+
+    def test_encode_ligatures(self):
+        self.encode(u"ﬀ ﬁ ﬂ ﬃ ﬄ ﬆ", br"ff fi fl ffi ffl st")
+
+    def test_encode_zero_width(self):
+        self.encode(u"1\u200b2\u200c3\u200d4", br"1\hspace{0pt}2{}34")
+
 
 class TestStreamEncoder(TestEncoder):
 
